bifurcan-clj.core

Common functions across all Bifurcan collections.

Common functions across all Bifurcan collections.
raw docstring

bifurcan-clj.int-map

Functions for working with IntegerMaps specifically: an efficient, persistent data structure mapping longs to objects. See also bifurcan-clj.map for general-purpose map operations.

Functions for working with IntegerMaps specifically: an efficient,
persistent data structure mapping longs to objects. See also
bifurcan-clj.map for general-purpose map operations.
raw docstring

bifurcan-clj.linear-list

Functions for working with linear lists, which are optimized for linear use, rather than efficient forking.

Functions for working with linear lists, which are optimized for linear use,
rather than efficient forking.
raw docstring

bifurcan-clj.util

Utility functions

Utility functions
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries